==> openshift-model-hive-5.12.3-sources.jar: io/fabric8/openshift/api/model/hive/v1/CheckpointBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CheckpointBuilder extends io.fabric8.openshift.api.model.hive.v1.CheckpointFluentImpl<io.fabric8.openshift.api.model.hive.v1.CheckpointBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.Checkpoint,io.fabric8.openshift.api.model.hive.v1.CheckpointBuilder>{
  public CheckpointBuilder() {
    this(false);
  }
  public CheckpointBuilder(java.lang.Boolean validationEnabled) {
    this(new Checkpoint(), validationEnabled);
  }
  public CheckpointBuilder(io.fabric8.openshift.api.model.hive.v1.CheckpointFluent<?> fluent) {
    this(fluent, false);
  }
  public CheckpointBuilder(io.fabric8.openshift.api.model.hive.v1.CheckpointFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Checkpoint(), validationEnabled);
  }
  public CheckpointBuilder(io.fabric8.openshift.api.model.hive.v1.CheckpointFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.Checkpoint instance) {
    this(fluent, instance, false);
  }
  public CheckpointBuilder(io.fabric8.openshift.api.model.hive.v1.CheckpointFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.Checkpoint instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CheckpointBuilder(io.fabric8.openshift.api.model.hive.v1.Checkpoint instance) {
    this(instance,false);
  }
  public CheckpointBuilder(io.fabric8.openshift.api.model.hive.v1.Checkpoint instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.CheckpointFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.Checkpoint build() {
    Checkpoint buildable = new Checkpoint(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CheckpointBuilder that = (CheckpointBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/CheckpointBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CheckpointBuilder extends CheckpointFluentImpl<CheckpointBuilder> implements VisitableBuilder<Checkpoint,CheckpointBuilder>{
  public CheckpointBuilder() {
    this(false);
  }
  public CheckpointBuilder(Boolean validationEnabled) {
    this(new Checkpoint(), validationEnabled);
  }
  public CheckpointBuilder(CheckpointFluent<?> fluent) {
    this(fluent, false);
  }
  public CheckpointBuilder(CheckpointFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Checkpoint(), validationEnabled);
  }
  public CheckpointBuilder(CheckpointFluent<?> fluent,Checkpoint instance) {
    this(fluent, instance, false);
  }
  public CheckpointBuilder(CheckpointFluent<?> fluent,Checkpoint instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CheckpointBuilder(Checkpoint instance) {
    this(instance,false);
  }
  public CheckpointBuilder(Checkpoint instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CheckpointFluent<?> fluent;
  Boolean validationEnabled;
  public Checkpoint build() {
    Checkpoint buildable = new Checkpoint(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
